"""
Strategy API endpoint links:
"""

TESTNET_LOTUS_LINK = "https://www.algoinvest.online/publicapi/lotus_bitmex_testnet"
LIVE_LOTUS_LINK = "https://www.algoinvest.online/publicapi/lotus_bitmex_live"
